/***************************************************************************
Name: View Cookies CS
Version: 1.0
Description: Basic cookie manager.
Author: Ron Beckman
Homepage: http://forum.softwareblaze.com
Email: scorpiondb@scorpiondb.com

Copyright (C) 2005  Ron Beckman

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to:

Free Software Foundation, Inc.
51 Franklin Street
Fifth Floor
Boston, MA  02110-1301
USA
***************************************************************************/



window.addEventListener('load', viewcookiescsInit, false);
window.addEventListener('unload', viewcookiescsExit, false);

function viewcookiescsInit() {
	viewcookiescsObserver.init();
	viewcookiescs.init();
}

function viewcookiescsExit() {
	viewcookiescsObserver.uninit();
}

var viewcookiescsObserver = {

	init: function() {
		var os = this.getObserver();
		os.addObserver(this, "cookie-changed", false);
	},

	observe: function(aCookie, aTopic, aData) {
		if (aCookie instanceof Components.interfaces.nsICookie) {
			if (aData=="deleted") viewcookiescs.checkCookie(aCookie);
		} else if (aData=="cleared" && viewcookiescs.protect.length>0) {
			viewcookiescs.addProtectedCookies();
		}
	},

	uninit: function() {
		var os = this.getObserver();
		os.removeObserver(this, "cookie-changed");
	},

	getObserver: function() {
		return Components.classes["@mozilla.org/observer-service;1"].
		getService(Components.interfaces.nsIObserverService);
	}
};


var viewcookiescs = {

	protect: [],

	getWin: function(name) {
		return Components.classes["@mozilla.org/appshell/window-mediator;1"].
		getService(Components.interfaces.nsIWindowMediator).
		getMostRecentWindow(name);
	},

	getPrefs: function() {
		return Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService).
		getBranch("viewcookiescs.");
	},

	getCookieManager2: function() {
		return Components.classes["@mozilla.org/cookiemanager;1"].
		getService(Components.interfaces.nsICookieManager2);
	},

	removeChars: function(arg) {
		return arg.replace(/[~!@#$%^&*()_+|`\-=\\\[\];',.\/{}:"<>? ]/g,'');
	},

	init: function() {
		//save protected cookies as array
		this.createProtected();

		//add protected cookies
		if (this.protect.length>0) this.addProtectedCookies();
	},

	createProtected: function() {
		var ckarray,name;
		var prefs = this.getPrefs();
		var protect = prefs.getCharPref('protected');
		if (protect) {
			protect = protect.split(',,');
			for (var i=0; i<protect.length; ++i) {
				if (!protect[i]) return false;
				this.protect.push(protect[i]);
			}
		}
		return false;
	},

	checkCookie: function(ck) {
		var cookie = ck.name + '||' + ck.value + '||' + ck.host + '||' + ck.path + '||' + ck.isSecure + '||' + ck.expires;

		for (var i=0; i<this.protect.length; ++i) {
			if (this.protect[i]==cookie) {
				var ses;
				var mngr = this.getCookieManager2();
				(ck.expires==0) ? ses = true : ses = false;
				mngr.add(ck.host,ck.path,ck.name,ck.value,ck.isSecure,ses,ck.expires);
				this.resetTree();
			}
		}
	},

	addProtectedCookies: function() {
		if (this.protect.length<1) return false;

		var ckarray,ses,win;
		var mngr = this.getCookieManager2();

		for (var i=0; i<this.protect.length; ++i) {
			if (!this.protect[i]) break;
			ckarray = this.protect[i].split('||');
			(ckarray[4]=='true') ? ckarray[4] = true : ckarray[4] = false;
			(ckarray[5]==0) ? ses = true : ses = false;
			mngr.add(ckarray[2],ckarray[3],ckarray[0],ckarray[1],ckarray[4],ses,ckarray[5]);
		}

		this.resetTree();
		return false;
	},

	resetTree: function() {
		//if cookies window is open reset tree
		win = this.getWin("Browser:Cookies");
		if (win && win.gCookiesWindow) win.gCookiesWindow.clearFilter();

		//if page info window is open reset tree
		win = this.getWin("Browser:page-info");
		if (win && win.csViewCookies) {
			//populate tree based on filter pref
			var list = win.document.getElementById('csVC-list');
			(list.selectedItem.id=='csVC-item-cur') ? win.csViewCookies.filterTree() : win.csViewCookies.load();
		}

		//if CS cookies window is open reset tree
		win = this.getWin("ViewCookiesCS:ViewCookies");
		if (win && win.csViewCookies) {
			//populate tree based on filter pref
			var list = win.document.getElementById('csVC-list');
			(list.selectedItem.id=='csVC-item-cur') ? win.csViewCookies.filterTree() : win.csViewCookies.load();
		}
	},

	viewCookiesCS: function() {
		window.openDialog("chrome://viewcookiescs/content/csViewCookies.xul","_blank","chrome,resizable=yes", null);
	}
};